# interfaz-link
Interfaz Link Python app

#DEV

- Python 3.6


    sudo add-apt-repository ppa:deadsnakes/ppa   
    sudo apt-get update  
    sudo apt install python3.6 python3.6-venv python-virtualenv
    virtualenv --python=python3.6 venv
    source venv/bin/activate
    
- PyQt5

    
    pip install PyQt5
    
- fbs


    pip install fbs    
    fbs run
    
   
   
